@@ -74,7 +74,7 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        KIMAP::DeleteJob *job = new KIMAP::DeleteJob(&session);
+        auto *job = new KIMAP::DeleteJob(&session);
         job->setMailBox(mailbox);
         bool result = job->exec();
         QEXPECT_FAIL("bad" , "Expected failure on BAD response", Continue);
