@@ -146,7 +146,7 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        KIMAP::GetQuotaRootJob *job = new KIMAP::GetQuotaRootJob(&session);
+        auto *job = new KIMAP::GetQuotaRootJob(&session);
         job->setMailBox(mailbox);
         bool result = job->exec();
         QEXPECT_FAIL("bad" , "Expected failure on BAD response", Continue);
