@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "getquotajob.h"
@@ -22,7 +9,7 @@
 #include <KLocalizedString>
 
 #include "quotajobbase_p.h"
-#include "message_p.h"
+#include "response_p.h"
 #include "session_p.h"
 
 namespace KIMAP
@@ -55,7 +42,7 @@ void GetQuotaJob::doStart()
     d->tags << d->sessionInternal()->sendCommand("GETQUOTA", '\"' + d->root + '\"');
 }
 
-void GetQuotaJob::handleResponse(const Message &response)
+void GetQuotaJob::handleResponse(const Response &response)
 {
     Q_D(GetQuotaJob);
     if (handleErrorReplies(response) == NotHandled) {
